# coding=utf-8
"""Tests for standard potentials"""

import os

import pyframe.readers

fragment_dict = {'HOH': ['O', 'H', 'H'], 'ACE': ['CH3', 'HH31', 'HH32', 'HH33', 'C', 'O', ],
                 'NME': ['CH3', 'HH31', 'HH32', 'HH33', 'N', 'H'], 'NHE': ['N', 'H1', 'H2'], 'NH2': ['N', 'H1', 'H2'],
                 'ALA': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'HB', 'O'],
                 'ARG': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'HD', 'HD', 'NE',
                         'HE', 'CZ', 'NH', 'NH', 'HH', 'HH', 'HH', 'HH'],
                 'ASN': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'OD', 'ND', 'HD', 'HD'],
                 'ASP': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'OD', 'OD'],
                 'CYS': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O', 'HG'],
                 'GLN': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'OE', 'NE', 'HE',
                         'HE'],
                 'GLU': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'OE', 'OE'],
                 'GLY': ['N', 'HN', 'CA', 'C', 'HA', 'HA', 'O'],
                 'HID': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'ND', 'CD', 'HD1', 'CE', 'NE', 'HD2',
                         'HE'],
                 'HIE': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'ND', 'CD', 'CE', 'NE', 'HD', 'HE1',
                         'HE2'],
                 'HIS': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'ND', 'CD', 'HD1', 'CE', 'NE', 'HD2',
                         'HE1', 'HE2'],
                 'ILE': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG2', 'CG1', 'O', 'HG2', 'HG2', 'HG2', 'HG1', 'HG1',
                         'CD', 'HD', 'HD', 'HD'],
                 'LEU': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'CD', 'CD', 'HD', 'HD', 'HD',
                         'HD', 'HD', 'HD'],
                 'LYS': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'HD', 'HD', 'CE',
                         'HE', 'HE', 'NZ', 'HZ', 'HZ', 'HZ'],
                 'MET': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'SD', 'CE', 'HE', 'HE',
                         'HE'],
                 'PHE': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'CD', 'CD', 'HD', 'CE', 'CE', 'HD',
                         'HE', 'CZ', 'HE', 'HZ'],
                 'PRO': ['N', 'CD', 'CA', 'HD', 'HD', 'CG', 'CB', 'HA', 'C', 'HG', 'HG', 'HB', 'HB', 'O'],
                 'SER': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'OG', 'O', 'HG'],
                 'THR': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG', 'OG', 'O', 'HG2', 'HG2', 'HG2', 'HG1'],
                 'TRP': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'CD1', 'CD2', 'HD', 'NE', 'CE2',
                         'CE3', 'HE1', 'CZ2', 'CZ3', 'HE3', 'HZ2', 'CH2', 'HZ3', 'HH2'],
                 'TYR': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'CD', 'CD', 'HD', 'CE', 'CE', 'HD',
                         'HE', 'CZ', 'HE', 'OH', 'HH'],
                 'VAL': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG', 'CG', 'O', 'HG', 'HG', 'HG', 'HG', 'HG', 'HG'],
                 'ASH': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'OD1', 'OD2', 'HD'],
                 'CYD': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O'],
                 'CYX': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O'],
                 'GLH': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'OE1', 'OE2', 'HE'],
                 'LYD': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'HD', 'HD', 'CE',
                         'HE', 'HE', 'NZ', 'HZ', 'HZ'],
                 'NALA': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'HB', 'O'],
                 'NARG': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'HD',
                          'HD', 'NE', 'HE', 'CZ', 'NH', 'NH', 'HH', 'HH', 'HH', 'HH'],
                 'NASN': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'OD', 'ND', 'HD', 'HD'],
                 'NASP': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'OD', 'OD'],
                 'NCYS': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O', 'HG'],
                 'NGLN': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'OE',
                          'NE', 'HE', 'HE'],
                 'NGLU': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'OE',
                          'OE'], 'NGLY': ['HN', 'HN', 'N', 'HN', 'CA', 'C', 'HA', 'HA', 'O'],
                 'NHID': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'ND', 'CD', 'HD1', 'CE',
                          'NE', 'HD2', 'HE'],
                 'NHIE': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'ND', 'CD', 'CE', 'NE',
                          'HD', 'HE1', 'HE2'],
                 'NHIS': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'ND', 'CD', 'HD1', 'CE',
                          'NE', 'HD2', 'HE1', 'HE2'],
                 'NILE': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG2', 'CG1', 'O', 'HG2', 'HG2', 'HG2',
                          'HG1', 'HG1', 'CD', 'HD', 'HD', 'HD'],
                 'NLEU': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'CD', 'CD', 'HD',
                          'HD', 'HD', 'HD', 'HD', 'HD'],
                 'NLYS': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'HD',
                          'HD', 'CE', 'HE', 'HE', 'NZ', 'HZ', 'HZ', 'HZ'],
                 'NMET': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'SD', 'CE',
                          'HE', 'HE', 'HE'],
                 'NPHE': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'CD', 'CD', 'HD', 'CE',
                          'CE', 'HD', 'HE', 'CZ', 'HE', 'HZ'],
                 'NPRO': ['HN', 'HN', 'N', 'CD', 'CA', 'HD', 'HD', 'CG', 'CB', 'HA', 'C', 'HG', 'HG', 'HB', 'HB', 'O'],
                 'NSER': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'OG', 'O', 'HG'],
                 'NTHR': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG', 'OG', 'O', 'HG2', 'HG2', 'HG2',
                          'HG1'],
                 'NTRP': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'CD1', 'CD2', 'HD', 'NE',
                          'CE2', 'CE3', 'HE1', 'CZ2', 'CZ3', 'HE3', 'HZ2', 'CH2', 'HZ3', 'HH2'],
                 'NTYR': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'CD', 'CD', 'HD', 'CE',
                          'CE', 'HD', 'HE', 'CZ', 'HE', 'OH', 'HH'],
                 'NVAL': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG', 'CG', 'O', 'HG', 'HG', 'HG', 'HG',
                          'HG', 'HG'],
                 'NASH': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'OD1', 'OD2', 'HD'],
                 'NCYD': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O'],
                 'NCYX': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O'],
                 'NGLH': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'OE1',
                          'OE2', 'HE'],
                 'NLYD': ['HN', 'HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'HD',
                          'HD', 'CE', 'HE', 'HE', 'NZ', 'HZ', 'HZ'],
                 'nALA': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'HB', 'O'],
                 'nARG': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'HD', 'HD',
                          'NE', 'HE', 'CZ', 'NH', 'NH', 'HH', 'HH', 'HH', 'HH'],
                 'nASN': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'OD', 'ND', 'HD', 'HD'],
                 'nASP': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'OD', 'OD'],
                 'nCYS': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O', 'HG'],
                 'nGLN': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'OE', 'NE',
                          'HE', 'HE'],
                 'nGLU': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'OE', 'OE'],
                 'nGLY': ['HN', 'N', 'HN', 'CA', 'C', 'HA', 'HA', 'O'],
                 'nHID': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'ND', 'CD', 'HD1', 'CE', 'NE',
                          'HD2', 'HE'],
                 'nHIE': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'ND', 'CD', 'CE', 'NE', 'HD',
                          'HE1', 'HE2'],
                 'nHIS': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'ND', 'CD', 'HD1', 'CE', 'NE',
                          'HD2', 'HE1', 'HE2'],
                 'nILE': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG2', 'CG1', 'O', 'HG2', 'HG2', 'HG2', 'HG1',
                          'HG1', 'CD', 'HD', 'HD', 'HD'],
                 'nLEU': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'CD', 'CD', 'HD', 'HD',
                          'HD', 'HD', 'HD', 'HD'],
                 'nLYS': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'HD', 'HD',
                          'CE', 'HE', 'HE', 'NZ', 'HZ', 'HZ', 'HZ'],
                 'nMET': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'SD', 'CE', 'HE',
                          'HE', 'HE'],
                 'nPHE': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'CD', 'CD', 'HD', 'CE', 'CE',
                          'HD', 'HE', 'CZ', 'HE', 'HZ'],
                 'nPRO': ['HN', 'N', 'CD', 'CA', 'HD', 'HD', 'CG', 'CB', 'HA', 'C', 'HG', 'HG', 'HB', 'HB', 'O'],
                 'nSER': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'OG', 'O', 'HG'],
                 'nTHR': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG', 'OG', 'O', 'HG2', 'HG2', 'HG2', 'HG1'],
                 'nTRP': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'CD1', 'CD2', 'HD', 'NE',
                          'CE2', 'CE3', 'HE1', 'CZ2', 'CZ3', 'HE3', 'HZ2', 'CH2', 'HZ3', 'HH2'],
                 'nTYR': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'CD', 'CD', 'HD', 'CE', 'CE',
                          'HD', 'HE', 'CZ', 'HE', 'OH', 'HH'],
                 'nVAL': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG', 'CG', 'O', 'HG', 'HG', 'HG', 'HG', 'HG',
                          'HG'],
                 'nASH': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'OD1', 'OD2', 'HD'],
                 'nCYD': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O'],
                 'nCYX': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O'],
                 'nGLH': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'OE1', 'OE2',
                          'HE'],
                 'nLYD': ['HN', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'HD', 'HD',
                          'CE', 'HE', 'HE', 'NZ', 'HZ', 'HZ'],
                 'cALA': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'HB', 'O1', 'O2', 'HO'],
                 'cARG': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O1', 'HG', 'HG', 'CD', 'HD', 'HD', 'NE',
                          'HE', 'CZ', 'NH', 'NH', 'HH', 'HH', 'HH', 'HH', 'O2', 'HO'],
                 'cASN': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O1', 'OD', 'ND', 'HD', 'HD', 'O2', 'HO'],
                 'cASP': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O1', 'OD', 'OD', 'O2', 'HO'],
                 'cCYS': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O1', 'HG', 'O2', 'HO'],
                 'cGLN': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O1', 'HG', 'HG', 'CD', 'OE', 'NE', 'HE',
                          'HE', 'O2', 'HO'],
                 'cGLU': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O1', 'HG', 'HG', 'CD', 'OE', 'OE', 'O2',
                          'HO'], 'cGLY': ['N', 'HN', 'CA', 'C', 'HA', 'HA', 'O1', 'O2', 'HO'],
                 'cHID': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O1', 'ND', 'CD', 'HD1', 'CE', 'NE',
                          'HD2', 'HE', 'O2', 'HO'],
                 'cHIE': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O1', 'ND', 'CD', 'CE', 'NE', 'HD', 'HE1',
                          'HE2', 'O2', 'HO'],
                 'cHIS': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O1', 'ND', 'CD', 'HD1', 'CE', 'NE',
                          'HD2', 'HE1', 'HE2', 'O2', 'HO'],
                 'cILE': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG2', 'CG1', 'O1', 'HG2', 'HG2', 'HG2', 'HG1', 'HG1',
                          'CD', 'HD', 'HD', 'HD', 'O2', 'HO'],
                 'cLEU': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O1', 'HG', 'CD', 'CD', 'HD', 'HD', 'HD',
                          'HD', 'HD', 'HD', 'O2', 'HO'],
                 'cLYS': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O1', 'HG', 'HG', 'CD', 'HD', 'HD', 'CE',
                          'HE', 'HE', 'NZ', 'HZ', 'HZ', 'HZ', 'O2', 'HO'],
                 'cMET': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O1', 'HG', 'HG', 'SD', 'CE', 'HE', 'HE',
                          'HE', 'O2', 'HO'],
                 'cPHE': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O1', 'CD', 'CD', 'HD', 'CE', 'CE', 'HD',
                          'HE', 'CZ', 'HE', 'HZ', 'O2', 'HO'],
                 'cPRO': ['N', 'CD', 'CA', 'HD', 'HD', 'CG', 'CB', 'HA', 'C', 'HG', 'HG', 'HB', 'HB', 'O1', 'O2', 'HO'],
                 'cSER': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'OG', 'O1', 'HG', 'O2', 'HO'],
                 'cTHR': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG', 'OG', 'O1', 'HG2', 'HG2', 'HG2', 'HG1', 'O2',
                          'HO'],
                 'cTRP': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O1', 'CD1', 'CD2', 'HD', 'NE', 'CE2',
                          'CE3', 'HE1', 'CZ2', 'CZ3', 'HE3', 'HZ2', 'CH2', 'HZ3', 'HH2', 'O2', 'HO'],
                 'cTYR': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O1', 'CD', 'CD', 'HD', 'CE', 'CE', 'HD',
                          'HE', 'CZ', 'HE', 'OH', 'HH', 'O2', 'HO'],
                 'cVAL': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG', 'CG', 'O1', 'HG', 'HG', 'HG', 'HG', 'HG', 'HG',
                          'O2', 'HO'],
                 'cASH': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O1', 'OD1', 'OD2', 'HD', 'O2', 'HO'],
                 'cCYD': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O1', 'O2', 'HO'],
                 'cCYX': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O1', 'O2', 'HO'],
                 'cGLH': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O1', 'HG', 'HG', 'CD', 'OE1', 'OE2',
                          'HE', 'O2', 'HO'],
                 'cLYD': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O1', 'HG', 'HG', 'CD', 'HD', 'HD', 'CE',
                          'HE', 'HE', 'NZ', 'HZ', 'HZ', 'O2', 'HO'],
                 'CALA': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'HB', 'O', 'O'],
                 'CARG': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'HD', 'HD', 'NE',
                          'HE', 'CZ', 'NH', 'NH', 'HH', 'HH', 'HH', 'HH', 'O'],
                 'CASN': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'OD', 'ND', 'HD', 'HD', 'O'],
                 'CASP': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'OD', 'OD', 'O'],
                 'CCYS': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O', 'HG', 'O'],
                 'CGLN': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'OE', 'NE', 'HE',
                          'HE', 'O'],
                 'CGLU': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'OE', 'OE', 'O'],
                 'CGLY': ['N', 'HN', 'CA', 'C', 'HA', 'HA', 'O', 'O'],
                 'CHID': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'ND', 'CD', 'HD1', 'CE', 'NE', 'HD2',
                          'HE', 'O'],
                 'CHIE': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'ND', 'CD', 'CE', 'NE', 'HD', 'HE1',
                          'HE2', 'O'],
                 'CHIS': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'ND', 'CD', 'HD1', 'CE', 'NE', 'HD2',
                          'HE1', 'HE2', 'O'],
                 'CILE': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG2', 'CG1', 'O', 'HG2', 'HG2', 'HG2', 'HG1', 'HG1',
                          'CD', 'HD', 'HD', 'HD', 'O'],
                 'CLEU': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'CD', 'CD', 'HD', 'HD', 'HD',
                          'HD', 'HD', 'HD', 'O'],
                 'CLYS': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'HD', 'HD', 'CE',
                          'HE', 'HE', 'NZ', 'HZ', 'HZ', 'HZ', 'O'],
                 'CMET': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'SD', 'CE', 'HE', 'HE',
                          'HE', 'O'],
                 'CPHE': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'CD', 'CD', 'HD', 'CE', 'CE', 'HD',
                          'HE', 'CZ', 'HE', 'HZ', 'O'],
                 'CPRO': ['N', 'CD', 'CA', 'HD', 'HD', 'CG', 'CB', 'HA', 'C', 'HG', 'HG', 'HB', 'HB', 'O', 'O'],
                 'CSER': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'OG', 'O', 'HG', 'O'],
                 'CTHR': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG', 'OG', 'O', 'HG2', 'HG2', 'HG2', 'HG1', 'O'],
                 'CTRP': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'CD1', 'CD2', 'HD', 'NE', 'CE2',
                          'CE3', 'HE1', 'CZ2', 'CZ3', 'HE3', 'HZ2', 'CH2', 'HZ3', 'HH2', 'O'],
                 'CTYR': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'CD', 'CD', 'HD', 'CE', 'CE', 'HD',
                          'HE', 'CZ', 'HE', 'OH', 'HH', 'O'],
                 'CVAL': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG', 'CG', 'O', 'HG', 'HG', 'HG', 'HG', 'HG', 'HG',
                          'O'],
                 'CASH': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'OD1', 'OD2', 'HD', 'O'],
                 'CCYD': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O', 'O'],
                 'CCYX': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O', 'O'],
                 'CGLH': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'OE1', 'OE2', 'HE',
                          'O'],
                 'CLYD': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'HD', 'HD', 'CE',
                          'HE', 'HE', 'NZ', 'HZ', 'HZ', 'O'],
                 'AALA': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'HB', 'O'],
                 'AARG': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O',
                          'HG', 'HG', 'CD', 'HD', 'HD', 'NE', 'HE', 'CZ', 'NH', 'NH', 'HH', 'HH', 'HH', 'HH'],
                 'AASN': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O',
                          'OD', 'ND', 'HD', 'HD'],
                 'AASP': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O',
                          'OD', 'OD'],
                 'ACYS': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O',
                          'HG'],
                 'AGLN': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O',
                          'HG', 'HG', 'CD', 'OE', 'NE', 'HE', 'HE'],
                 'AGLU': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O',
                          'HG', 'HG', 'CD', 'OE', 'OE'],
                 'AGLY': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'C', 'HA', 'HA', 'O'],
                 'AHID': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O',
                          'ND', 'CD', 'HD1', 'CE', 'NE', 'HD2', 'HE'],
                 'AHIE': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O',
                          'ND', 'CD', 'CE', 'NE', 'HD', 'HE1', 'HE2'],
                 'AHIS': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O',
                          'ND', 'CD', 'HD1', 'CE', 'NE', 'HD2', 'HE1', 'HE2'],
                 'AILE': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG2', 'CG1',
                          'O', 'HG2', 'HG2', 'HG2', 'HG1', 'HG1', 'CD', 'HD', 'HD', 'HD'],
                 'ALEU': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O',
                          'HG', 'CD', 'CD', 'HD', 'HD', 'HD', 'HD', 'HD', 'HD'],
                 'ALYS': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O',
                          'HG', 'HG', 'CD', 'HD', 'HD', 'CE', 'HE', 'HE', 'NZ', 'HZ', 'HZ', 'HZ'],
                 'AMET': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O',
                          'HG', 'HG', 'SD', 'CE', 'HE', 'HE', 'HE'],
                 'APHE': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O',
                          'CD', 'CD', 'HD', 'CE', 'CE', 'HD', 'HE', 'CZ', 'HE', 'HZ'],
                 'APRO': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'CD', 'CA', 'HD', 'HD', 'CG', 'CB', 'HA', 'C', 'HG',
                          'HG', 'HB', 'HB', 'O'],
                 'ASER': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'OG', 'O',
                          'HG'],
                 'ATHR': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG', 'OG', 'O',
                          'HG2', 'HG2', 'HG2', 'HG1'],
                 'ATRP': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O',
                          'CD1', 'CD2', 'HD', 'NE', 'CE2', 'CE3', 'HE1', 'CZ2', 'CZ3', 'HE3', 'HZ2', 'CH2', 'HZ3',
                          'HH2'],
                 'ATYR': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O',
                          'CD', 'CD', 'HD', 'CE', 'CE', 'HD', 'HE', 'CZ', 'HE', 'OH', 'HH'],
                 'AVAL': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG', 'CG', 'O',
                          'HG', 'HG', 'HG', 'HG', 'HG', 'HG'],
                 'AASH': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O',
                          'OD1', 'OD2', 'HD'],
                 'ACYD': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O'],
                 'ACYX': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O'],
                 'AGLH': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O',
                          'HG', 'HG', 'CD', 'OE1', 'OE2', 'HE'],
                 'ALYD': ['CY', 'OY', 'CAY', 'HY', 'HY', 'HY', 'N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O',
                          'HG', 'HG', 'CD', 'HD', 'HD', 'CE', 'HE', 'HE', 'NZ', 'HZ', 'HZ'],
                 'BALA': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'HB', 'O', 'NT', 'HNT', 'CAT', 'HT', 'HT',
                          'HT'],
                 'BARG': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'HD', 'HD', 'NE',
                          'HE', 'CZ', 'NH', 'NH', 'HH', 'HH', 'HH', 'HH', 'NT', 'HNT', 'CAT', 'HT', 'HT', 'HT'],
                 'BASN': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'OD', 'ND', 'HD', 'HD', 'NT', 'HNT',
                          'CAT', 'HT', 'HT', 'HT'],
                 'BASP': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'OD', 'OD', 'NT', 'HNT', 'CAT', 'HT',
                          'HT', 'HT'],
                 'BCYS': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O', 'HG', 'NT', 'HNT', 'CAT', 'HT', 'HT',
                          'HT'],
                 'BGLN': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'OE', 'NE', 'HE',
                          'HE', 'NT', 'HNT', 'CAT', 'HT', 'HT', 'HT'],
                 'BGLU': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'OE', 'OE', 'NT',
                          'HNT', 'CAT', 'HT', 'HT', 'HT'],
                 'BGLY': ['N', 'HN', 'CA', 'C', 'HA', 'HA', 'O', 'NT', 'HNT', 'CAT', 'HT', 'HT', 'HT'],
                 'BHID': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'ND', 'CD', 'HD1', 'CE', 'NE', 'HD2',
                          'HE', 'NT', 'HNT', 'CAT', 'HT', 'HT', 'HT'],
                 'BHIE': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'ND', 'CD', 'CE', 'NE', 'HD', 'HE1',
                          'HE2', 'NT', 'HNT', 'CAT', 'HT', 'HT', 'HT'],
                 'BHIS': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'ND', 'CD', 'HD1', 'CE', 'NE', 'HD2',
                          'HE1', 'HE2', 'NT', 'HNT', 'CAT', 'HT', 'HT', 'HT'],
                 'BILE': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG2', 'CG1', 'O', 'HG2', 'HG2', 'HG2', 'HG1', 'HG1',
                          'CD', 'HD', 'HD', 'HD', 'NT', 'HNT', 'CAT', 'HT', 'HT', 'HT'],
                 'BLEU': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'CD', 'CD', 'HD', 'HD', 'HD',
                          'HD', 'HD', 'HD', 'NT', 'HNT', 'CAT', 'HT', 'HT', 'HT'],
                 'BLYS': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'HD', 'HD', 'CE',
                          'HE', 'HE', 'NZ', 'HZ', 'HZ', 'HZ', 'NT', 'HNT', 'CAT', 'HT', 'HT', 'HT'],
                 'BMET': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'SD', 'CE', 'HE', 'HE',
                          'HE', 'NT', 'HNT', 'CAT', 'HT', 'HT', 'HT'],
                 'BPHE': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'CD', 'CD', 'HD', 'CE', 'CE', 'HD',
                          'HE', 'CZ', 'HE', 'HZ', 'NT', 'HNT', 'CAT', 'HT', 'HT', 'HT'],
                 'BPRO': ['N', 'CD', 'CA', 'HD', 'HD', 'CG', 'CB', 'HA', 'C', 'HG', 'HG', 'HB', 'HB', 'O', 'NT', 'HNT',
                          'CAT', 'HT', 'HT', 'HT'],
                 'BSER': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'OG', 'O', 'HG', 'NT', 'HNT', 'CAT', 'HT', 'HT',
                          'HT'],
                 'BTHR': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG', 'OG', 'O', 'HG2', 'HG2', 'HG2', 'HG1', 'NT',
                          'HNT', 'CAT', 'HT', 'HT', 'HT'],
                 'BTRP': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'CD1', 'CD2', 'HD', 'NE', 'CE2',
                          'CE3', 'HE1', 'CZ2', 'CZ3', 'HE3', 'HZ2', 'CH2', 'HZ3', 'HH2', 'NT', 'HNT', 'CAT', 'HT', 'HT',
                          'HT'],
                 'BTYR': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'CD', 'CD', 'HD', 'CE', 'CE', 'HD',
                          'HE', 'CZ', 'HE', 'OH', 'HH', 'NT', 'HNT', 'CAT', 'HT', 'HT', 'HT'],
                 'BVAL': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'CG', 'CG', 'O', 'HG', 'HG', 'HG', 'HG', 'HG', 'HG',
                          'NT', 'HNT', 'CAT', 'HT', 'HT', 'HT'],
                 'BASH': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'OD1', 'OD2', 'HD', 'NT', 'HNT',
                          'CAT', 'HT', 'HT', 'HT'],
                 'BCYD': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O', 'NT', 'HNT', 'CAT', 'HT', 'HT',
                          'HT'],
                 'BCYX': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'SG', 'O', 'NT', 'HNT', 'CAT', 'HT', 'HT',
                          'HT'],
                 'BGLH': ['N', 'HN', 'CA', 'HA', 'CB', 'C', 'HB', 'HB', 'CG', 'O', 'HG', 'HG', 'CD', 'OE1', 'OE2', 'HE',
                          'NT', 'HNT', 'CAT', 'HT', 'HT', 'HT']}


def test_fragment_charge():
    data_dir = '{0}/../data'.format(os.path.dirname(__file__))
    for pot_file in os.listdir(data_dir):
        file_name, file_ext = os.path.splitext(pot_file)
        potential = pyframe.readers.read_potential_file(file_name)
        for fragment_name, atom_names in fragment_dict.items():
            fragment_charge = 0.0
            if file_name == 'sep':
                if fragment_name == 'ACE' or fragment_name == 'PHE':
                    continue
            if fragment_name in potential:
                for atom_name in atom_names:
                    fragment_charge += potential[fragment_name][atom_name]['M0']
                assert abs(fragment_charge - float(round(fragment_charge))) < 1.0e-5
